%cardioid
% Constructs a Cardioid from circles drawn relative to equi-spaced marks
% around the circumference of a unit circle.
%
% Andy French & Stephen French. December 2020.

function cardioid

% Number of equi-spaced marks around circumference of the unit circle.
N = 48;

%Position of cardioid point (0,ycp) that all circles pass through
ycp = -1;

%

%Coordinates of equi-spaced points along unit circle circumference
theta = linspace(0,2*pi,N+1);
xc = cos(theta); yc = sin(theta);

%Create figure and plot (black) circles. Use a bitmap editing tool like
%IrfanView to edit, colour in etc.
fig = figure('name','cardioid','color',[1 1 1]); 
ax = axes('nextplot','add');
theta = linspace(0,2*pi,1000); %Array of circle angles in radians.
for n=1:N
    %Radius of circle r is distance from unit cicle circumference point
    % ( xc(n), yc(n) ) to cardioid point (0,ycp).
    r = sqrt( xc(n)^2 + ( yc(n) - ycp )^2 );
    x = r*cos(theta) + xc(n); y = r*sin(theta) + yc(n);
    plot( x,y, 'k','linewidth',0.1 );
end

%Set axes to be equally scaled, and remove axes grid
axis equal; axis off;

%Export figure as a 600DPI PNG file and close figure
print( gcf, ['cardioid ',num2str(N),' ycp=',num2str(ycp),'.png'],'-dpng','-r600' );
close(gcf);

%End of code