%ellipse
% Constructs an ellipse from circles drawn relative to equi-spaced marks
% along a unit circle diameter.
%
% Andy French & Stephen French. December 2020.

function ellipse

% Number of equi-spaced marks along diameter of unit circle
N = 60;

%

%Circle centre marks
xc = linspace( -1,1,N);

%Circle centre y coordinates, on the circumference of a unit circle.
yc = sqrt( 1 - xc.^2 );

%Create figure and plot (black) circles. Use a bitmap editing tool like
%IrfanView to edit, colour in etc.
fig = figure('name','ellipse','color',[1 1 1]); 
ax = axes('nextplot','add');
theta = linspace(0,2*pi,1000); %Array of circle angles in radians.
for n=1:N
    x = yc(n)*cos(theta) + xc(n); y = yc(n)*sin(theta);
    plot( x,y, 'k','linewidth',0.1 );
end

%Set axes to be equally scaled, and remove axes grid
axis equal; axis off;

%Export figure as a 600DPI PNG file and close figure
print( gcf, ['ellipse ',num2str(N),'.png'],'-dpng','-r600' );
close(gcf);

%End of code